<?php
/*
Plugin Name: Post Date Randomizer
Description: Simple plugin that changes the date of all published posts to any random date in the past or future. Visit "Post Date Randomizer" setting in the dasboard meny to setup date range.
Version:     1.0.0
Author:      Anty
Author URI:  https://profiles.wordpress.org/wellbeingtips
License:     GPL3
License URI: http://www.gnu.org/licenses/gpl-3.0.html
*/

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

// Adding settings

add_action('admin_menu','pdrdaddSubMenuPage');
function pdrdaddSubMenuPage(){
    add_menu_page(
			__('Randomizer', 'pdr_rnd'),
			__('Randomizer', 'pdr_rnd'),
			'manage_options',
			'pdr_random_posts',
			'pdr_settings',
            'dashicons-calendar-alt'

		);
    
}
function pdr_settings(){
    ?>
	    <div class="wrap">
	    <h1>Post Date Randomizer</h1>
	    <form method="post" action="options.php">
	        <?php
	            settings_fields("pdr_rnd_section");
	            do_settings_sections("pdr_rnd_options");      
	            submit_button(); 
	        ?>          
	    </form>
        <a class="button button-secondary" href="<?php echo wp_nonce_url(admin_url('options-general.php?page=pdr_random_posts&randomize=yes'),'pdr_rd_randomize', 'pdr_rd_nonce')?>">Randomize</a>
		</div>
	<?php
}
add_action("admin_init", "pdr_settings_fields");
function pdr_settings_fields(){
    add_settings_section("pdr_rnd_section", "All Settings", null, "pdr_rnd_options");
	
	
	add_settings_field("pdr_date1", "Start Date:", "pdr_date1_element", "pdr_rnd_options", "pdr_rnd_section");
	add_settings_field("pdr_date2", "End Date", "pdr_date2_element", "pdr_rnd_options", "pdr_rnd_section");
    
    
    register_setting("pdr_rnd_section", "pdr_date1");
    register_setting("pdr_rnd_section", "pdr_date2");
}
function pdr_date1_element(){
    $date_format = 'Y-m-d H:i:s';
    $date1 = get_option('pdr_date1',date( $date_format, strtotime("-1 year", time()) ));
    ?>
    
    <input name="pdr_date1" type="text" id="pdr_date1" value="<?php echo $date1?>" class="regular-text code">
    <?php
}
function pdr_date2_element(){
    $date_format = 'Y-m-d H:i:s';
    $date2 = get_option('pdr_date2',date( $date_format, time() ));
    ?>
    
    <input name="pdr_date2" type="text" id="pdr_date2" value="<?php echo $date2?>" class="regular-text code">
    <?php
}
add_action('init', 'pdr_randomize');
function pdr_randomize(){
    $randomize = isset($_REQUEST['randomize']) ? $_REQUEST['randomize'] : '';
    if (isset($_GET['pdr_rd_nonce']) && wp_verify_nonce($_GET['pdr_rd_nonce'], 'pdr_rd_randomize')){ 
        if ($randomize == 'yes') {
            $date_format = 'Y-m-d H:i:s';
            $date1 = get_option('pdr_date1',date( $date_format, strtotime("-1 year", time()) ));
            $date2 = get_option('pdr_date2',date( $date_format, time() ));
            //* Get all the posts
            $posts = get_posts( array( 'numberposts' => -1, 'post_status' => 'any' ) );
            foreach( $posts as $post ) {

            //* Generate a random post dates
            $random_date = mt_rand( strtotime( $date1 ), strtotime($date2) );
            //* Format the date that WordPress likes
            $post_date = date( $date_format, $random_date );

            // We only want to update the post date
            $update = array(
            'ID' => $post->ID,
            'post_date' => $post_date,
            'post_date_gmt' => null,
            );

            //* Update the post
            wp_update_post( $update );

            }
            // Notice of sucess after action
            add_action( 'admin_notices', 'pdr_acf_notice' );
        }
    }
}
function pdr_acf_notice() {
  ?>
  <div class="success notice">
      <p><?php _e( 'Posts Randomized.', 'pdr_rnd' ); ?></p>
  </div>
  <?php
}
